pub fn estimate_tool_defs_tokens(tools: &[ToolDefinition]) -> u32Expand description
Rough token estimate for tool definitions attached to a chat request.
pub fn estimate_tool_defs_tokens(tools: &[ToolDefinition]) -> u32Rough token estimate for tool definitions attached to a chat request.