pub fn should_compact_session(
session: &Session,
system_prompt: &str,
agent: &AgentConfig,
) -> boolExpand description
Whether the session should be compacted based on estimated token usage.
pub fn should_compact_session(
session: &Session,
system_prompt: &str,
agent: &AgentConfig,
) -> boolWhether the session should be compacted based on estimated token usage.